# Inputs
INPUTS = 'inputs'
INPUT_STATE = 'inputs/{input_id}'

# Consolidation V2
CONSOLIDATION = 'consolidation'
CONSOLIDATION_V2 = 'v2/consolidation'
CONSOLIDATION_STATE_V2 = 'v2/consolidation/{query_id}'
CONSOLIDATION_RUN_V2 = 'v2/consolidation/{query_id}/run'
